Museum

Home

Lab Overview

Retrotechnology Articles

Online Manuals

⇒ fsck(8) — GENIX 4.1A

Media Vault

Software Library

Restoration Projects

Artifacts Sought

Related Articles

fstab(5)

fs(5)

crash(8)

reboot(8)



      FSCK(8)                 GENIX Programmer's Manual                 FSCK(8)



      NAME
           fsck - file system consistency check and interactive repair

      SYNOPSIS
           /etc/fsck -p [ filesystem ...  ]
           /etc/fsck [ -y ] [ -n ] [ -sX ] [ -SX ] [ -t filename ] [ filesystem
           ] ...

      DESCRIPTION
           The first form of fsck preens a standard set of filesystems  or  the
           specified  file  systems.  It is normally used in the script /etc/rc
           during  automatic  reboot.   In  this  case  fsck  reads  the  table
           /etc/fstab  to  determine  which file systems to check.  It uses the
           information there to inspect groups of disks in parallel taking max-
           imum  advantage  of i/o overlap to check the file systems as quickly
           as possible.  Normally, the root file system will be checked on pass
           1,  other  ``root''  (``a'' partition) file systems on pass 2, other
           small file systems on separate passes (e.g. the ``d''  file  systems
           on  pass  3  and  the ``e'' file systems on pass 4), and finally the
           large user file systems on the last  pass,  e.g.  pass  5.   A  pass
           number of 0 in fstab causes a disk to not be checked; similarly par-
           titions which are not shown as to be mounted ``rw''  or  ``ro''  are
           not checked.

           The system takes care that only  a  restricted  class  of  innocuous
           inconsistencies  can  happen  unless  hardware  or software failures
           intervene.  These are limited to the following:

                Unreferenced inodes

                Link counts in inodes too large

                Missing blocks in the free list

                Blocks in the free list also in files

                Counts in the super-block wrong

           These are the only inconsistencies which fsck  with  the  -p  option
           will  correct; if it encounters other inconsistencies, it exits with
           an abnormal return status and an automatic reboot  will  then  fail.
           For  each  corrected inconsistency one or more lines will be printed
           identifying the file system on which the correction will take place,
           and  the  nature of the correction.  After successfully correcting a
           file system, fsck will print the number of files on that file system
           and the number of used and free blocks.

           Without the -p option, fsck audits and interactively repairs  incon-
           sistent  conditions  for  file systems. If the file system is incon-
           sistent the operator is prompted for concurrence before each correc-
           tion  is attempted.  It should be noted that a number of the correc-
           tive actions which are not fixable under the -p option  will  result



      Printed 11/16/83                                                        1





      FSCK(8)                 GENIX Programmer's Manual                 FSCK(8)



           in  some  loss of data.  The amount and severity of data lost may be
           determined from the diagnostic output.  The default action for  each
           consistency correction is to wait for the operator to respond yes or
           no.  If the operator  does  not  have  write  permission  fsck  will
           default to a -n action.

           Fsck has  more  consistency  checks  than  its  predecessors  check,
           dcheck, fcheck, and icheck combined.

           The following flags are interpreted by fsck.

           -y    Assume a yes response to all questions  asked  by  fsck;  this
                 should be used with great caution as this is a free license to
                 continue after essentially unlimited trouble has been  encoun-
                 tered.

           -n    Assume a no response to all questions asked by  fsck;  do  not
                 open the file system for writing.

           -sX   Ignore the actual free list and (unconditionally)  reconstruct
                 a new one by rewriting the super-block of the file system. The
                 file system should be unmounted while this is done; if this is
                 not  possible,  care should be taken that the system is quies-
                 cent and that it is  rebooted  immediately  afterwards.   This
                 precaution  is necessary so that the old, bad, in-core copy of
                 the superblock will not continue to be used, or written on the
                 file system.

                 The -sX option allows for creating an optimal free-list organ-
                 ization.   The following forms of X are supported for the fol-
                 lowing devices:

                      -s3 (RP03)
                      -s4 (RP04, RP05, RP06)
                      -sBlocks-per-cylinder:Blocks-to-skip (for anything else)

                 If X is not given, the values used  when  the  filesystem  was
                 created  are  used.   If these values were not specified, then
                 the value 400:9 is used.

           -SX   Conditionally reconstruct the free list. This option  is  like
                 -sX  above  except that the free list is rebuilt only if there
                 were no discrepancies discovered in the file system. Using  -S
                 will  force a no response to all questions asked by fsck. This
                 option is useful  for  forcing  free  list  reorganization  on
                 uncontaminated file systems.

           -t    If fsck cannot obtain enough memory to  keep  its  tables,  it
                 uses  a  scratch file. If the -t option is specified, the file
                 named in the next argument is used as  the  scratch  file,  if
                 needed. Without the -t flag, fsck will prompt the operator for
                 the name of the scratch file. The file chosen should not be on



      Printed 11/16/83                                                        2





      FSCK(8)                 GENIX Programmer's Manual                 FSCK(8)



                 the  filesystem being checked, and if it is not a special file
                 or did not already exist, it is removed when fsck completes.

           If no filesystems are given to fsck then a default list of file sys-
           tems is read from the file /etc/fstab.

           Inconsistencies checked are as follows:

           1.    Blocks claimed by more than one inode or the free list.
           2.    Blocks claimed by an inode or the free list outside the  range
                 of the file system.
           3.    Incorrect link counts.
           4.    Size checks:
                       Directory size not 16-byte aligned.
           5.    Bad inode format.
           6.    Blocks not accounted for anywhere.
           7.    Directory checks:
                       File pointing to unallocated inode.
                       Inode number out of range.
           8.    Super Block checks:
                       More than 65536 inodes.
                       More blocks for inodes than there are in the  file  sys-
                       tem.
           9.    Bad free block list format.
           10.   Total free block and/or free inode count incorrect.

           Orphaned files and directories  (allocated  but  unreferenced)  are,
           with  the operator's concurrence, reconnected by placing them in the
           lost+found directory.  The name assigned is the  inode  number.  The
           only  restriction  is that the directory lost+found must preexist in
           the root of the filesystem being checked and must have  empty  slots
           in  which  entries  can  be  made.   This  is accomplished by making
           lost+found, copying a number of files to  the  directory,  and  then
           removing them (before fsck is executed).

           Checking the raw device is almost always faster.

      FILES
           /etc/fstab           contains default list of file systems to check.

      DIAGNOSTICS
           The  diagnostics  produced  by  fsck  are  intended  to   be   self-
           explanatory.

      SEE ALSO
           fstab(5), fs(5), crash(8), reboot(8)

      BUGS
           Inode numbers for .  and ..  in each directory should be checked for
           validity.





      Printed 11/16/83                                                        3





      FSCK(8)                 GENIX Programmer's Manual                 FSCK(8)



           -g and -b options from check should be available in fsck.

           There should be some way to start a fsck -p at pass n.




















































      Printed 11/16/83                                                        4



Typewritten Software • bear@typewritten.org • Edmonds, WA 98026